/// <reference path="jquery.d.ts"/>
/// <reference path="lib.ts"/>
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var logic;
(function (logic) {
    /**
    * Collection
    */
    var Collection = (function () {
        function Collection(id, target) {
            this._id = id;
            this._target = target;
        }
        Collection.prototype.getId = function () {
            return this._id;
        };

        Collection.prototype.getTarget = function () {
            return this._target;
        };
        return Collection;
    })();
    logic.Collection = Collection;

    /**
    * Const
    */
    var Const = (function () {
        function Const() {
        }
        Const.ID_SCENE_01 = "scene01";
        Const.ID_SCENE_02 = "scene02";
        Const.ID_SCENE_03 = "scene03";
        return Const;
    })();
    logic.Const = Const;
})(logic || (logic = {}));

var display;
(function (display) {
    var navigation;
    (function (navigation) {
        /**
        * Navigation
        */
        var Navigation = (function () {
            function Navigation(root, target) {
                this._root = root;
                this._$target = target;
                this._collections = [];

                //
                var $btn01 = this._$target.find("#btn01");
                var btn01Id = $btn01.attr("data-id");
                this._btn01 = new Button(this._root, btn01Id, $btn01);
                this._collections.push(new logic.Collection(btn01Id, this._btn01));

                //
                var $btn02 = this._$target.find("#btn02");
                var btn02Id = $btn02.attr("data-id");
                this._btn02 = new Button(this._root, btn02Id, $btn02);
                this._collections.push(new logic.Collection(btn02Id, this._btn02));

                //
                var $btn03 = this._$target.find("#btn03");
                var btn03Id = $btn03.attr("data-id");
                this._btn03 = new Button(this._root, btn03Id, $btn03);
                this._collections.push(new logic.Collection(btn03Id, this._btn03));
            }
            Navigation.prototype.init = function () {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info = this._collections[i];
                    var target = info.getTarget();
                    target.init();
                }
            };

            Navigation.prototype.changeScene = function (id) {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info = this._collections[i];
                    var target = info.getTarget();
                    if (info.getId() == id) {
                        target.deleteActive();
                        target.setCurrent();
                    } else {
                        target.setActive();
                        target.deleteCurrent();
                    }
                }
            };
            return Navigation;
        })();
        navigation.Navigation = Navigation;

        /**
        * Button
        */
        var Button = (function (_super) {
            __extends(Button, _super);
            function Button(root, id, target) {
                _super.call(this, id, target);
                this._root = root;
            }
            Button.prototype.init = function () {
            };

            Button.prototype.onClick = function (e) {
                e.preventDefault();
                if (this.isActive) {
                    // changeSceneEvent
                    this._root.changeSceneEvent(this.id);
                }
            };
            return Button;
        })(lib.lib_button.BaseButton);
        navigation.Button = Button;
    })(navigation || (navigation = {}));
    var scenes;
    (function (scenes) {
        /**
        * Scenes
        */
        var Scenes = (function () {
            function Scenes(root, target) {
                this._root = root;
                this._$target = target;
                this._collections = [];

                //
                var scene01 = this._$target.find("#scene01");
                var scene01Id = scene01.attr("data-id");
                this._scene01 = new Scene(this._root, scene01Id, scene01);
                this._collections.push(new logic.Collection(scene01Id, this._scene01));

                //
                var scene02 = this._$target.find("#scene02");
                var scene02Id = scene02.attr("data-id");
                this._scene02 = new Scene(this._root, scene02Id, scene02);
                this._collections.push(new logic.Collection(scene02Id, this._scene02));

                //
                var scene03 = this._$target.find("#scene03");
                var scene03Id = scene03.attr("data-id");
                this._scene03 = new Scene(this._root, scene03Id, scene03);
                this._collections.push(new logic.Collection(scene03Id, this._scene03));
            }
            Scenes.prototype.init = function () {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info = this._collections[i];
                    var target = info.getTarget();
                    target.init();
                }
            };

            Scenes.prototype.changeScene = function (id) {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info = this._collections[i];
                    var target = info.getTarget();
                    if (info.getId() == id) {
                        target.open();
                    } else {
                        target.close();
                    }
                }
            };
            return Scenes;
        })();
        scenes.Scenes = Scenes;

        /**
        * Scene
        */
        var Scene = (function (_super) {
            __extends(Scene, _super);
            function Scene(root, id, target) {
                _super.call(this, id, target);
                this._root = root;
            }
            Scene.prototype.init = function () {
            };
            return Scene;
        })(lib.lib_display.BaseDisplay);
        scenes.Scene = Scene;
    })(scenes || (scenes = {}));

    /**
    * Main
    */
    var Main = (function () {
        function Main(target) {
            this._$target = target;
            this._navigation = new navigation.Navigation(this, $("#nav"));
            this._scenes = new scenes.Scenes(this, $("#scenes"));
        }
        Main.prototype.init = function () {
            this._navigation.init();
            this._scenes.init();

            // changeSceneEvent
            this.changeSceneEvent(logic.Const.ID_SCENE_01);
        };

        Main.prototype.changeSceneEvent = function (id) {
            if (typeof id === "undefined") { id = logic.Const.ID_SCENE_01; }
            this._navigation.changeScene(id);
            this._scenes.changeScene(id);
        };
        return Main;
    })();
    display.Main = Main;
})(display || (display = {}));

$(function () {
    var main = new display.Main($("body"));
    main.init();
});
//# sourceMappingURL=index.js.map
