/// <reference path="jquery.d.ts"/>
/// <reference path="lib.ts"/>

module logic {

    /**
     * Collection
     */
    export class Collection {

        private _id:string;
        private _target:any;

        constructor(id:string, target:any) {
            this._id = id;
            this._target = target;
        }

        public getId() :string {
            return this._id;
        }

        public getTarget() :any {
            return this._target;
        }

    }

    /**
     * Const
     */
    export class Const {

        static ID_SCENE_01:string = "scene01";
        static ID_SCENE_02:string = "scene02";
        static ID_SCENE_03:string = "scene03";

    }

}

module display {
    module navigation {

        /**
         * Navigation
         */
        export class Navigation {

            private _root:display.Main;
            private _$target:JQuery;
            private _collections:Array<logic.Collection>;
            private _btn01:Button;
            private _btn02:Button;
            private _btn03:Button;

            constructor(root:display.Main, target:JQuery) {
                this._root = root;
                this._$target = target;
                this._collections = [];
                //
                var $btn01:JQuery = this._$target.find("#btn01");
                var btn01Id:string = $btn01.attr("data-id");
                this._btn01 = new Button(this._root, btn01Id, $btn01);
                this._collections.push(new logic.Collection(btn01Id, this._btn01));
                //
                var $btn02:JQuery = this._$target.find("#btn02");
                var btn02Id:string = $btn02.attr("data-id");
                this._btn02 = new Button(this._root, btn02Id, $btn02);
                this._collections.push(new logic.Collection(btn02Id, this._btn02));
                //
                var $btn03:JQuery = this._$target.find("#btn03");
                var btn03Id:string = $btn03.attr("data-id");
                this._btn03 = new Button(this._root, btn03Id, $btn03);
                this._collections.push(new logic.Collection(btn03Id, this._btn03));
            }

            public init() :void {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info:logic.Collection = this._collections[i];
                    var target:lib.lib_button.IButton =  info.getTarget();
                    target.init();
                }
            }

            public changeScene(id) :void {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info:logic.Collection = this._collections[i];
                    var target:lib.lib_button.IButton =  info.getTarget();
                    if (info.getId() == id) {
                        target.deleteActive();
                        target.setCurrent();
                    } else {
                        target.setActive();
                        target.deleteCurrent();
                    }
                }
            }

        }

        /**
         * Button
         */
        export class Button extends lib.lib_button.BaseButton implements lib.lib_button.IButton{

            private _root:display.Main;

            constructor(root:display.Main, id:string, target:JQuery) {
                super(id, target);
                this._root = root;
            }

            public init() :void {
            }

            public onClick(e:JQueryEventObject) :void {
                e.preventDefault();
                if (this.isActive) {
                    // changeSceneEvent
                    this._root.changeSceneEvent(this.id);
                }
            }

        }

    }
    module scenes {

        /**
         * Scenes
         */
        export class Scenes {

            private _root:display.Main;
            private _$target:JQuery;
            private _collections:Array<logic.Collection>;
            private _scene01:Scene;
            private _scene02:Scene;
            private _scene03:Scene;

            constructor(root:display.Main, target:JQuery) {
                this._root = root;
                this._$target = target;
                this._collections = [];
                //
                var scene01:JQuery = this._$target.find("#scene01");
                var scene01Id:string = scene01.attr("data-id");
                this._scene01 = new Scene(this._root, scene01Id, scene01);
                this._collections.push(new logic.Collection(scene01Id, this._scene01));
                //
                var scene02:JQuery = this._$target.find("#scene02");
                var scene02Id:string = scene02.attr("data-id");
                this._scene02 = new Scene(this._root, scene02Id, scene02);
                this._collections.push(new logic.Collection(scene02Id, this._scene02));
                //
                var scene03:JQuery = this._$target.find("#scene03");
                var scene03Id:string = scene03.attr("data-id");
                this._scene03 = new Scene(this._root, scene03Id, scene03);
                this._collections.push(new logic.Collection(scene03Id, this._scene03));
            }

            public init() :void {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info:logic.Collection = this._collections[i];
                    var target:lib.lib_display.IDisplay =  info.getTarget();
                    target.init();
                }
            }

            public changeScene(id) :void {
                var i = 0, max;
                for (i = 0, max = this._collections.length; i < max; i = i + 1) {
                    var info:logic.Collection = this._collections[i];
                    var target:lib.lib_display.IDisplay =  info.getTarget();
                    if (info.getId() == id) {
                        target.open();
                    } else {
                        target.close();
                    }
                }
            }

        }

        /**
         * Scene
         */
        export class Scene extends lib.lib_display.BaseDisplay implements lib.lib_display.IDisplay {

            private _root:display.Main;

            constructor(root:display.Main, id:string, target:JQuery) {
                super(id, target);
                this._root = root;
            }

            public init() :void {
            }

        }

    }

    /**
     * Main
     */
    export class Main {

        private _$target:JQuery;
        private _navigation:navigation.Navigation;
        private _scenes:scenes.Scenes;

        constructor(target:JQuery) {
            this._$target = target;
            this._navigation = new navigation.Navigation(this, $("#nav"));
            this._scenes = new scenes.Scenes(this, $("#scenes"));
        }

        public init() :void {
            this._navigation.init();
            this._scenes.init();
            // changeSceneEvent
            this.changeSceneEvent(logic.Const.ID_SCENE_01);
        }

        public changeSceneEvent(id:String = logic.Const.ID_SCENE_01) :void {
            this._navigation.changeScene(id);
            this._scenes.changeScene(id);
        }

    }

}

$(function () {

    var main:display.Main = new display.Main($("body"));
    main.init();

});

