/// <reference path="jquery.d.ts"/>

module lib {
    export module lib_button {

        export interface IButton {

            init() :void;
            setActive() :void;
            deleteActive() :void;
            setCurrent() :void;
            deleteCurrent() :void;

        }

        /**
         * BaseButton
         */
        export class BaseButton implements IButton {

            public $target:JQuery;
            public id:string;
            public isActive:boolean = false;
            public isCurrent:boolean = false;

            constructor(id:string, target:JQuery) {
                this.id = id;
                this.$target = target;
                this.$target.css({cursor: "default"});
                //
                var scope = this;
                this.$target.on("click", function(e:JQueryEventObject){
                    scope.onClick(e);
                });
                this.$target.on("mouseenter", function(e:JQueryEventObject){
                    scope.onOver(e);
                });
                this.$target.on("mouseleave", function(e:JQueryEventObject){
                    scope.onOut(e);
                });
            }

            public init() :void {
            }

            public getId() :string {
                return this.id;
            }

            public setActive() :void {
                if (this.isActive) {
                    return;
                }
                this.isActive = true;
                this.$target.css({cursor: "pointer"});
            }

            public deleteActive() :void {
                if (!this.isActive) {
                    return;
                }
                this.isActive = false;
                this.$target.css({cursor: "default"});
            }

            public setCurrent() :void {
                if (this.isCurrent) {
                    return;
                }
                this.isCurrent = true;
                this.$target.addClass("current");
                this.$target.removeClass("over");
            }

            public deleteCurrent() :void {
                if (!this.isCurrent) {
                    return;
                }
                this.isCurrent = false;
                this.$target.removeClass("current");
                this.$target.removeClass("over");
            }

            public onOver(e:JQueryEventObject) :void {
                if (!this.isCurrent && this.isActive) {
                    this.$target.addClass("over");
                }
            }

            public onOut(e:JQueryEventObject) :void {
                if (!this.isCurrent && this.isActive) {
                    this.$target.removeClass("over");
                }
            }

            public onClick(e:JQueryEventObject) :void {
                e.preventDefault();
                if (this.isActive) {
                    console.log("_onClick : " + this.id);
                }
            }

        }
    }
    export module lib_display {

        export interface IDisplay {

            init() :void;
            getId() :string;
            open() :void;
            close() :void;

        }

        /**
         * BaseDisplay
         */
        export class BaseDisplay implements IDisplay {

            public $target:JQuery;
            public id:string;
            public isOpen:boolean = false;

            constructor(id:string, target:JQuery) {
                this.id = id;
                this.$target = target;
                this.$target.css({display: "none"});
            }

            public init() :void {
            }

            public getId() :string {
                return this.id;
            }

            public open() :void {
                if (this.isOpen) {
                    return;
                }
                this.isOpen = true;
                this.onOpen();
            }

            public onOpen() :void {
                this.$target.css({display: "block"});
                this.completeOpen();
            }

            public completeOpen() :void {
            }

            public close() :void {
                if (!this.isOpen) {
                    return;
                }
                this.isOpen = false;
                this.onClose();
            }

            public onClose() :void {
                this.$target.css({display: "none"});
                this.completeClose();
            }

            public completeClose() :void {
            }

        }
    }

}